IntoLevelPredicate

Trait IntoLevelPredicate 

pub trait IntoLevelPredicate {
    type Predicate: Predicate<Level>;

    // Required method
    fn into_predicate(self) -> Self::Predicate;
}
Conversion into a predicate for Levels used in the level() function.

Required Associated Types

type Predicate: Predicate<Level>

Predicate output of the conversion. The exact type should be considered an implementation detail and should not be relied upon.

Required Methods

fn into_predicate(self) -> Self::Predicate

Performs the conversion.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoLevelPredicate for Level

Source

impl IntoLevelPredicate for LevelFilter

Source

impl<P: Predicate<Level>> IntoLevelPredicate for [P; 1]

Implementors